From 1c207a7756ac37906fb47161f3c72273ecae6e6f Mon Sep 17 00:00:00 2001
From: Paul Eggert <eggert@Penguin.CS.UCLA.EDU>
Date: Wed, 12 Apr 2017 11:24:41 -0700
Subject: [PATCH] Allow bypassing of some checks when merging

* build-aux/git-hooks/pre-commit:
Merge blindly if GIT_MERGE_BLINDLY is true.
---
 build-aux/git-hooks/pre-commit | 19 ++++++++++++++++---
 1 file changed, 16 insertions(+), 3 deletions(-)

diff --git a/build-aux/git-hooks/pre-commit b/build-aux/git-hooks/pre-commit
index 6483bfc..ae41f90 100755
--- a/build-aux/git-hooks/pre-commit
+++ b/build-aux/git-hooks/pre-commit
@@ -25,16 +25,29 @@ LC_ALL=
 
 . git-sh-setup
 
+# When GIT_MERGE_BLINDLY is 'true', then when doing a two-way merge,
+# ignore problems that came from the other side of the merge.
+head=HEAD
+if test "$GIT_MERGE_BLINDLY" = true && test -e "$GIT_DIR"/MERGE_HEAD; then
+  merge_heads=`cat "$GIT_DIR"/MERGE_HEAD` || exit
+  for merge_head in $merge_heads; do
+    case $head in
+      HEAD) head=$merge_head;;
+      *) head=HEAD; break;;
+    esac
+  done
+fi
+
 git_diff='git diff --cached --name-only --diff-filter=A'
 ok_chars='\0+[=-=]./0-9A-Z_a-z'
-nbadchars=`$git_diff -z HEAD | tr -d "$ok_chars" | wc -c`
+nbadchars=`$git_diff -z $head; done | tr -d "$ok_chars" | wc -c`
 
 if test "$nbadchars" -ne 0; then
   echo "File name does not consist of -+./_ or ASCII letters or digits."
   exit 1
 fi
 
-for new_name in `$git_diff HEAD`; do
+for new_name in `$git_diff $head`; do
   case $new_name in
     -* | */-*)
       echo "$new_name: File name component begins with '-'."
@@ -53,4 +66,4 @@ nbadchars=
 # tests so that trailing spaces are generated on the fly rather than
 # being committed as source.
 
-exec git diff-index --check --cached HEAD --
+exec git diff-index --check --cached $head --
-- 
2.9.3

